Learn R Programming

imputeYn (version 1.3)

print.imputeYn: Printing the Important Components of the Class "imputeYn"

Description

Print the imputed value for the censored largest datum.

Usage

"print"(x, digits = max(3, getOption("digits") - 3), ...)

Arguments

x
the object of class "imputeYn".
digits
outputs with how many digits. Default is 3.
...
not used.

Value

Gives three important components of the class "imputeYn"- the imputed value for the last largest censored datum, coefficients of the covariates after tail correction, and coefficients of the covariates for dataset with imputed last datum.

Details

Print the imputed value for the censored largest datum, the coefficients of the covariates with or without the imputed value. The coefficients that consider the imputated value are labelled as "new coefficients."

References

Khan and Shaw. (2013a). On Dealing with Censored Largest Observations under Weighted Least Squares. CRiSM working paper, Department of Statistics, University of Warwick, UK, No. 13-07. Also available in http://arxiv.org/abs/1312.2533.

See Also

imputeYn

Examples

Run this code
# For uncorrelated dataset
data1<-data(n=100, p=4, r=0, b1=c(2,2,3,3), sig=1, Cper=0)
imp<-imputeYn(data1$x, data1$y, data1$delta, method = "condMean", beta=NULL)
print(imp)

# For correlated dataset
data2<-data(n=100, p=4, r=0.5, b1=c(2,2,3,3), sig=1, Cper=0)
imp2<-imputeYn(data2$x, data2$y, data2$delta, method = "condMean", beta=NULL)
print(imp2)

Run the code above in your browser using DataLab