Compute Kaplan-Meier weights for weighted least squares method.
Usage
aft.kmweight(Y, delta)
Arguments
Y
survival time.
delta
status.
Value
kmwt
The Kaplan Meier weights
Details
Compute Kaplan-Meier weights that are used for weighted least squares to solve the AFT model under right censoring. This gives weights that are computed after implementation of Efron's (1967) tail correction.
References
Stute, W. (1993). Consistent estimation under random censorship when covariables are available. Journal of Multivariate Analysis, 45 , 89-103.
Efron, B. (1967). The two sample problem with censored data. In Proceedings of the fifth Berkeley symposium on mathematical statistics and probability, Vol. 4, p. 831-853.
# For dataset where the last largest datum is censored and censoring level is 50 percentdata1<-data(n=100, p=2, r=0, b1=c(2,4), sig=1, Cper=0)
kmw<-aft.kmweight(data1$y,data1$delta)
kmw